/*
 * Copyright (c) 2008, Luc Yriarte
 * All rights reserved.
 * 
 * @file Matrix.java
 * @author Luc Yriarte
 * 
 * License: BSD <http://www.opensource.org/licenses/bsd-license.php>
 * 
 * Redistribution and use in source and binary forms, with or without modification, are permitted 
 * provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice, this 
 * list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright notice, this 
 * list of conditions and the following disclaimer in the documentation and/or other materials 
 * provided with the distribution.
 *     * The name of Luc Yriarte may not be used to endorse or promote products derived 
 * from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR 
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND 
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 * 
 */
package org.yriarte.physicSim;

import org.yriarte.math.Vector;
import org.yriarte.mini3D.Object3D;
import org.yriarte.mini3D.Vector3D;

/**
 * SolidObject : A weighted 3D Object 
 * 
 * Physics units in m / kg / s
 * Left handed geometric coordinates
 * 
 */
public class SolidObject extends PointMass {
	/** Geometric object to draw.  */
	public Object3D object3D;
	
	/**
	 * 
	 */
	public SolidObject() {
		super();
	}
	
	/**
	 * @param mass
	 */
	public SolidObject(double m) {
		super(m);
	}
	
	/**
	 * @param mass
	 * @param object3D
	 */
	public SolidObject(double m, Object3D object3D) {
		super(m);
		this.object3D = object3D;
	}

	public void setPosition(Vector position) {
		super.setPosition(position);
		object3D.setPosition(new Vector3D(position).positionMatrix());
		
	}

	/**
	 * @param dt
	 */
	public PointMass updateState(double dt) {
		super.updateState(dt);
		object3D.setPosition(new Vector3D(position).positionMatrix());
		return this;
	}
		
}
