/*
 * Copyright (c) 2008, Luc Yriarte
 * All rights reserved.
 * 
 * @file Matrix.java
 * @author Luc Yriarte
 * 
 * License: BSD <http://www.opensource.org/licenses/bsd-license.php>
 * 
 * Redistribution and use in source and binary forms, with or without modification, are permitted 
 * provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice, this 
 * list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright notice, this 
 * list of conditions and the following disclaimer in the documentation and/or other materials 
 * provided with the distribution.
 *     * The name of Luc Yriarte may not be used to endorse or promote products derived 
 * from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR 
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND 
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 * 
 */
package org.yriarte.physicSim;

import org.yriarte.math.Vector;

public class Spring extends ForceGenerator {
	/** spring length at rest */
	public double length=1;
	public double stiffness=0.01;
	public Vector stretch;
	
	/**
	 * 
	 */
	public Spring() {
		super();
	}

	/**
	 * @param stretch
	 * default stiffness is 1. 
	 * length is the norm of the stretch vector
	 */
	public Spring(Vector stretch) {
		super();
		this.stiffness = 1;
		this.stretch = stretch;
		this.length = stretch.norm();
System.out.println("Spring length " + length);
	}
	
	/**
	 * @param stiffness
	 * @param stretch
	 * length is the norm of the stretch vector
	 */
	public Spring(double stiffness, Vector stretch) {
		super();
		this.stiffness = stiffness;
		this.stretch = stretch;
		this.length = stretch.norm();
	}
	
	/**
	 * @param length
	 * @param stiffness
	 * vertical stretch vector of length descending the y axis
	 */
	public Spring(double length, double stiffness) {
		super();
		this.length = length;
		this.stiffness = stiffness;
		this.stretch = new VectorXYZ(0,-length,0);
	}
	
	public Vector getForceVector() {
		return Vector.MatrixAsVector(stretch.unitVector().mulNumThis(-stiffness*(stretch.norm()-length)));
	}
}
