/*
 * Copyright (c) 2008, Luc Yriarte
 * All rights reserved.
 * 
 * @file Matrix.java
 * @author Luc Yriarte
 * 
 * License: BSD <http://www.opensource.org/licenses/bsd-license.php>
 * 
 * Redistribution and use in source and binary forms, with or without modification, are permitted 
 * provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice, this 
 * list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright notice, this 
 * list of conditions and the following disclaimer in the documentation and/or other materials 
 * provided with the distribution.
 *     * The name of Luc Yriarte may not be used to endorse or promote products derived 
 * from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR 
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND 
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 * 
 */
package org.yriarte.physicSim;

import org.yriarte.math.Matrix;
import org.yriarte.math.Vector;


public class VectorXYZ extends Vector {

	static public VectorXYZ MatrixAsVectorXYZ(Matrix aMatrix) {
		return new VectorXYZ(aMatrix.getCell());
	}
	
	/**
	 * @brief [0,0,0] column vector
	 */
	public VectorXYZ() {
		super(3);
	}

	/**
	 * @brief [x,y,z] column vector
	 */
	public VectorXYZ(double x, double y, double z) {
		super(3);
		cell[0][0] = x;
		cell[1][0] = y;
		cell[2][0] = z;
	}
	
	public VectorXYZ(double[][] cell) {
		nLines = 3;
		nCols = 1;
		this.cell = cell;
	}

	public VectorXYZ(Matrix aMatrix) {
		super(3);
		cell[0][0] = aMatrix.getCell()[0][0];
		cell[1][0] = aMatrix.getCell()[1][0];
		cell[2][0] = aMatrix.getCell()[2][0];
	}

	public double getX() {
		return cell[0][0];
	}
	
	public double getY() {
		return cell[1][0];
	}
	
	public double getZ() {
		return cell[2][0];
	}
	
	public VectorXYZ setX(double aDouble) {
		cell[0][0] = aDouble;
		return this;
	}
	
	public VectorXYZ setY(double aDouble) {
		cell[1][0] = aDouble;
		return this;
	}
	
	public VectorXYZ setZ(double aDouble) {
		cell[2][0] = aDouble;
		return this;
	}
	
	
}
